<?php
/* Author: Marton Horvath */
/* Date: 2015 */
/* File: plot.php */

require_once 'my_phplot.php';

/* Suppressing error messages to standard output */
ini_set('display_errors', 'off');

$PLOT_X_DIMENSION = 750;
$PLOT_Y_DIMENSION = 750;

define('E', 2.718282);
define('PI', M_PI);

function ndst($x)
{
	return ( 1/2 + 1/2 * ( (pow(E, 0.8*$x) - pow(E, -0.8*$x)) / (pow(E, 0.8*$x)+pow(E, -0.8*$x)) ) );
}
function i_ndst($x)
{
	return ( 5/8 * log($x / (1/$x)) );
}
function logndst($x)
{
	return ( ndst(log($x)) );
}

function cot($x)
{
	return ( 1 / tan($x) );
}
function acot($x)
{
	if ($x > 1.0) return atan( 1.0/$x );
   else if ($x < -1.0) return ( M_PI + atan(1.0/$x) );
   else return ( M_PI/2 - atan($x) );
}
function coth($x)
{
	return ( (pow(E, $x) + pow(E, -$x)) / (pow(E, $x) - pow(E, -$x)) );
}
function acoth($x)
{
	if ($x >= -1 && $x <= 1) return NAN;
	else return ( 1/2 * log(abs((1 + $x) / (1 - $x))) );
}

function integer($x)
{
	return (int)($x);
}

/* Definition of custom logarithm function because standard version of php log() function returns INF, -INF in case of invalid input values */
function myLog($x)
{
	if($x <= 0) throw new Exception('');
	return log($x);
}

/* Definition of expression checking method (both semantic and syntax errors) */
function expression_is_ok($expression)
{
	// Definition of available words in expression
	$available_words = array('log', 'exp', 'pow', 'sqrt', 'sin', 'cos', 'tan', 'cot', 'asin', 'acos', 'atan', 'acot', 'sinh', 'cosh', 'tanh', 'coth', 'asinh', 'acosh', 'atanh', 'acoth', 'pi', 'integer', 'e', 'ndst', 'logndst', 'x');
	// Removing SPACEs from expression
	$expression = str_replace(' ', '', $expression);
	// Splitting expression by valid delimiters
	$substrings = preg_split( "/[+-\/*(),]/", $expression );
	// Checking semantic errors
	for($i=0; $i<count($substrings); $i++)
	{
		// Return FALSE when substring is neither empty nor numeric nor available world nor independent variable
		if ( !($substrings[$i] == '') && !is_numeric($substrings[$i]) && !in_array(strtolower($substrings[$i]), $available_words) && !(strtolower($substrings[$i]) == 'x') ) 
		{
			return false;
		}
	}

	// Checking syntax errors. Return FALSE if syntax error found TRUE otherwise

	try
	{
		ob_start();
		$err = eval($expression . ';');
		ob_end_clean();
	}catch(Exception $e){}
	return (gettype($err)=="NULL") ? true : false;
	
}

/* Creating PLOT object */
$PLOT = new my_phplot($PLOT_X_DIMENSION, $PLOT_Y_DIMENSION);

/* Checking GRAPH section */
	/* Expression1 field */
		//Initial state
		if(!isset($_POST['expression1']))
		{
			$PLOT->input1 = 'x'; 
		}
		// Field is empty
		else if($_POST['expression1'] == '')
		{
			array_push($PLOT->ERROR_MESSAGES, '- GRAPH error: Filling <i>f(x)</i> field is required. <br>');
		}
		// Expression is invalud
		else if( !expression_is_ok($_POST['expression1']) )
		{
			array_push($PLOT->ERROR_MESSAGES, '- GRAPH error: <i>f(x)</i> formula is invalid. <br>');
		}
		// Field is filled
		else 
		{
			$PLOT->input1 = $_POST['expression1']; 
		}
	/* Expression2 field */
		//Initial state
		if(!isset($_POST['expression2']))
		{
			$PLOT->input2 = ''; 
		}
		// Expression is invalud
		else if( !expression_is_ok($_POST['expression2']) )
		{
			array_push($PLOT->ERROR_MESSAGES, '- GRAPH error: <i>g(x)</i> formula is invalid. <br>');
		}
		// Field is filled
		else 
		{
			$PLOT->input2 = $_POST['expression2']; 
		}
	/* Expression3 field */
		//Initial state
		if(!isset($_POST['expression3']))
		{
			$PLOT->input3 = ''; 
		}
		// Expression is invalud
		else if( !expression_is_ok($_POST['expression3']) )
		{
			array_push($PLOT->ERROR_MESSAGES, '- GRAPH error: <i>h(x)</i> formula is invalid. <br>');
		}
		// Field is filled
		else 
		{
			$PLOT->input3 = $_POST['expression3']; 
		}
	/* Expression4 field */
		//Initial state
		if(!isset($_POST['expression4']))
		{
			$PLOT->input4 = ''; 
		}
		// Expression is invalud
		else if( !expression_is_ok($_POST['expression4']) )
		{
			array_push($PLOT->ERROR_MESSAGES, '- GRAPH error: <i>i(x)</i> formula is invalid. <br>');
		}
		// Field is filled
		else 
		{
			$PLOT->input4 = $_POST['expression4']; 
		}


	/* Plot_density field */	
		// Normal case
		if(isset($_POST['plot_density']))
		{
			switch($_POST['plot_density'])
			{
				case 'high': $PLOT->set_plot_detail(10000); break;
				case 'very_high': $PLOT->set_plot_detail(20000); break;
				default: $PLOT->set_plot_detail(5000); break;
			}
		}

	/* Thick plot field */
		// Initial state
		if(!isset($_POST['thick_plot']))
		{
			$PLOT->SetPointSizes(1);
		}
		// Normal case
		else
		{
			if($_POST['thick_plot'] == 'true') 
			{
				$PLOT->SetPointSizes(2);
			}
			else 
			{
				$PLOT->SetPointSizes(1);
			}
		}

/* Setting plot title */	
	// $PLOT->SetTitle('graph: f(x) = ' . $input1);
	
/* Creating function from input string (replacing 'log' to 'myLog' in input string, see myLog())*/	
	$PLOT->input1 = str_replace(' ', '', $PLOT->input1);
	// $input = str_replace('log(', 'myLog(', $input);
	$PLOT->input1 = strtolower($PLOT->input1);
	$PLOT->input1 = str_replace('pi', 'PI', $PLOT->input1);
	$PLOT->input1 = str_replace('e', 'E', $PLOT->input1);
	$PLOT->input1 = str_replace('x', '$x', $PLOT->input1);
	$PLOT->input1 = str_replace('$xp', 'xp', $PLOT->input1);
	$new_function1 = create_function('$x', 'return(' . $PLOT->input1 . '); ');

	if($PLOT->input2 != '')
	{
		$PLOT->input2 = str_replace(' ', '', $PLOT->input2);
		$PLOT->input2 = strtolower($PLOT->input2);
		$PLOT->input2 = str_replace('pi', 'PI', $PLOT->input2);
		$PLOT->input2 = str_replace('e', 'E', $PLOT->input2);
		$PLOT->input2 = str_replace('x', '$x', $PLOT->input2);
		$PLOT->input2 = str_replace('$xp', 'xp', $PLOT->input2);
		$new_function2 = create_function('$x', 'return(' . $PLOT->input2 . '); ');
	}
	else
	{
		$new_function2 = NULL;
	}
	if($PLOT->input3 != '')
	{
		$PLOT->input3 = str_replace(' ', '', $PLOT->input3);
		$PLOT->input3 = strtolower($PLOT->input3);
		$PLOT->input3 = str_replace('pi', 'PI', $PLOT->input3);
		$PLOT->input3 = str_replace('e', 'E', $PLOT->input3);
		$PLOT->input3 = str_replace('x', '$x', $PLOT->input3);
		$PLOT->input3 = str_replace('$xp', 'xp', $PLOT->input3);
		$new_function3 = create_function('$x', 'return(' . $PLOT->input3 . '); ');
	}
	else
	{
		$new_function3 = NULL;
	}
	if($PLOT->input4 != '')
	{
		$PLOT->input4 = str_replace(' ', '', $PLOT->input4);
		$PLOT->input4 = strtolower($PLOT->input4);
		$PLOT->input4 = str_replace('pi', 'PI', $PLOT->input4);
		$PLOT->input4 = str_replace('e', 'E', $PLOT->input4);
		$PLOT->input4 = str_replace('x', '$x', $PLOT->input4);
		$PLOT->input4 = str_replace('$xp', 'xp', $PLOT->input4);
		$new_function4 = create_function('$x', 'return(' . $PLOT->input4 . '); ');
	}
	else
	{
		$new_function4 = NULL;
	}
	

/* Checking and setting X AXIS section */
	/* X_axis_scale field */	
		// Initial state
		if(!isset($_POST['x_axis_scale']))
		{
			$PLOT->SetXScaleType('linear');
		}
		// Normal case (selection)
		else
		{
			$PLOT->SetXScaleType($_POST['x_axis_scale']);
		}

	/* X_axis_scale_parameter field */	
		// Initial state
		if($PLOT->GetXScaleType() == 'root' || $PLOT->GetXScaleType() == 'power')
		{
			if(!isset($_POST['x_scale_parameter']) || $_POST['x_scale_parameter'] == '')
			{
				array_push($PLOT->ERROR_MESSAGES, '- X AXIS error: Filling <i>Scale parameter</i> field is required. <br>');
			}
			// Field is filled with invalid data
			else if(!is_numeric($_POST['x_scale_parameter']))
			{
				array_push($PLOT->ERROR_MESSAGES, '- X AXIS error: <i>Scale parameter</i> must be numeric. <br>');
			}
			// Normal case (selection)
			else
			{
				if($_POST['x_scale_parameter'] <= 0)
				{
					array_push($PLOT->ERROR_MESSAGES, '- X AXIS error: <i>Scale parameter</i> must be greater than 0. <br>');
				}
				else
				{
					$PLOT->X_scale_parameter = $_POST['x_scale_parameter'];
				}
			}
		}

	/* X_axis_scale_min field */	
		// Initial state
		if(!isset($_POST['x_axis_scale_min']))
		{
			$_POST['x_axis_scale_min'] = -5;
		}
		// Field is not filled
		else if($_POST['x_axis_scale_min'] == '')
		{
			array_push($PLOT->ERROR_MESSAGES, '- X AXIS error: Filling <i>Scale MIN</i> field is required. <br>');
		}
		// Field is filled with invalid data
		else if(!is_numeric($_POST['x_axis_scale_min']))
		{
			array_push($PLOT->ERROR_MESSAGES, '- X AXIS error: <i>Scale MIN</i> must be numeric. <br>');
		}
		// Field is filled with invalid number when scale type is LOG
		else if( ($_POST['x_axis_scale'] == 'logarithm' ) &&  $_POST['x_axis_scale_min'] <= 0)
		{
			array_push($PLOT->ERROR_MESSAGES, '- X AXIS error: Minimum of <i>logarithm</i> scale must be grather than 0. <br>');
		}
		// Field is filled with invalid number when scale type is root or power
		else if( ($_POST['x_axis_scale'] == 'root' || $_POST['x_axis_scale'] == 'power') &&  $_POST['x_axis_scale_min'] < 0)
		{
			array_push($PLOT->ERROR_MESSAGES, '- X AXIS error: Minimum of <i>root</i> / <i>power</i> scale must be grather or equal than 0. <br>');
		}
		// SQRT axis scale started from 0 (!!)
		else if( ($_POST['x_axis_scale'] == 'root') &&  $_POST['x_axis_scale_min'] == 0)
		{
			$_POST['x_axis_scale_min'] = 1E-10;
		}
		// Field is filled with invalid number when scale type is reciprocal
		else if( ($_POST['x_axis_scale'] == 'reciprocal') &&  $_POST['x_axis_scale_min'] >= -1)
		{
			array_push($PLOT->ERROR_MESSAGES, '- X AXIS error: Minimum of <i>reciprocal</i> scale must be less than -1. <br>');
		}
		// Field is filled with invalid number when scale type is tan
		else if( ($_POST['x_axis_scale'] == 'tan' ) &&  $_POST['x_axis_scale_min'] <= -1.5707963267949)
		{
			array_push($PLOT->ERROR_MESSAGES, '- X AXIS error: Minimum of <i>tan</i> scale must be grather than -1.5707963267949. <br>');
		}
		// Field is filled with invalid number when scale type is atanh
		else if( ($_POST['x_axis_scale'] == 'atanh' ) &&  $_POST['x_axis_scale_min'] <= -1)
		{
			array_push($PLOT->ERROR_MESSAGES, '- X AXIS error: Minimum of <i>atanh</i> scale must be grather than -1. <br>');
		}
		// Field is filled with invalid number when scale type is lognormal
		else if( ($_POST['x_axis_scale'] == 'lognormal' ) &&  $_POST['x_axis_scale_min'] <= 0)
		{
			array_push($PLOT->ERROR_MESSAGES, '- X AXIS error: Minimum of <i>lognormal</i> scale must be grather than 0. <br>');
		}

	/* X_axis_scale_max field */	
		// Initial state
		if(!isset($_POST['x_axis_scale_max']))
		{
			$_POST['x_axis_scale_max'] = 5;
		}
		// Field is not filled
		else if($_POST['x_axis_scale_max'] == '')
		{
			array_push($PLOT->ERROR_MESSAGES, '- X AXIS error: Filling <i>Scale MAX</i> field is required. <br>');
		}
		// Field is filled with invalid data
		else if(!is_numeric($_POST['x_axis_scale_max']))
		{
			array_push($PLOT->ERROR_MESSAGES, '- X AXIS error: <i>Scale MAX</i> must be numeric. <br>');
		}
		// Field is filled with invalid number when scale type is reciprocal
		else if( ($_POST['x_axis_scale'] == 'reciprocal') &&  $_POST['x_axis_scale_max'] <= 1)
		{
			array_push($PLOT->ERROR_MESSAGES, '- X AXIS error: Maximum of <i>reciprocal</i> scale must be greater than 1. <br>');
		}
		// Field is filled with invalid number when scale type is tan
		else if( ($_POST['x_axis_scale'] == 'tan' ) &&  $_POST['x_axis_scale_max'] >= 1.5707963267949)
		{
			array_push($PLOT->ERROR_MESSAGES, '- X AXIS error: Maximum of <i>tan</i> scale must be less than 1.5707963267949. <br>');
		}
		// Field is filled with invalid number when scale type is tan
		else if( ($_POST['x_axis_scale'] == 'atanh' ) &&  $_POST['x_axis_scale_max'] >= 1)
		{
			array_push($PLOT->ERROR_MESSAGES, '- X AXIS error: Maximum of <i>atanh</i> scale must be less than 1. <br>');
		}

	/* X_tick_anchor field */	
		// Initial state
		if(!isset($_POST['x_tick_anchor']) || $_POST['x_tick_anchor'] == '')
		{
			$PLOT->SetXTickAnchor(1);
		}
		// Field is filled with invalid data
		else if(!is_numeric($_POST['x_tick_anchor']))
		{
			array_push($PLOT->ERROR_MESSAGES, '- X AXIS error: <i>Tick anchor</i> must be numeric. <br>');
		}
		// Normal case
		else
		{
			$PLOT->SetXTickAnchor($_POST['x_tick_anchor']);
		}

	/* X_tick_increment field */	
		// Initial state
		if(!isset($_POST['x_tick_increment']) || $_POST['x_tick_increment'] == '')
		{
			$PLOT->SetXTickIncrement(1);
		}
		// Field is filled with invalid data
		else if(!is_numeric($_POST['x_tick_increment']))
		{
			array_push($PLOT->ERROR_MESSAGES, '- X AXIS error: <i>Tick increment</i> must be numeric. <br>');
		}
		// Tick increment is equal or less than 0
		else if($_POST['x_tick_increment'] <= 0)
		{
			array_push($PLOT->ERROR_MESSAGES, '- X AXIS error: Tick incrementation value must be greater than 0. <br>');
		}
		// Normal case
		else
		{
			$PLOT->SetXTickIncrement($_POST['x_tick_increment']);
		}

	/* X_draw_grid field */	
		// Initial state
		if(!isset($_POST['x_draw_grid']))
		{
			$PLOT->SetDrawXGrid(TRUE);
		}
		// Normal case
		else
		{
			if($_POST['x_draw_grid'] == 'true') 
			{
				$PLOT->SetDrawXGrid(TRUE);
			}
			else 
			{
				$PLOT->SetDrawXGrid(FALSE);
			}
		}

	/* Y_axis_position field (hidden) */	
		// Initial state
		if($_POST['x_axis_scale'] == 'logarithm' )
		{
			$PLOT->SetYAxisPosition(1);
		}
		else if($_POST['x_axis_scale'] == 'exponent' )
		{
			$PLOT->SetYAxisPosition($_POST['y_axis_scale_min']);
		}
		else if($_POST['x_axis_scale'] == 'normal' )
		{
			$PLOT->set_y_axis_pos(0.5);
		}
		else
		{
			$PLOT->SetYAxisPosition(0);
		}


/* Checking and setting Y AXIS section */
	/* Y_axis_scale field */	
		// Initial state
		if(!isset($_POST['y_axis_scale']))
		{
			$PLOT->SetYScaleType('linear');
		}
		// Normal case
		else
		{
			$PLOT->SetYScaleType($_POST['y_axis_scale']);
		}

	/* Y_axis_scale_parameter field */	
		// Initial state
		if($PLOT->GetYScaleType() == 'root' || $PLOT->GetYScaleType() == 'power')
		{
			if(!isset($_POST['y_scale_parameter']) || $_POST['y_scale_parameter'] == '')
			{
				array_push($PLOT->ERROR_MESSAGES, '- Y AXIS error: Filling <i>Scale parameter</i> field is required. <br>');
				
			}
			// Normal case (selection)
			else
			{
				if($_POST['y_scale_parameter'] <= 0)
				{
					array_push($PLOT->ERROR_MESSAGES, '- Y AXIS error: <i>Scale parameter</i> must be greater than 0. <br>');
				}
				else
				{
					$PLOT->Y_scale_parameter = $_POST['y_scale_parameter'];
				}
			}
		}

	/* Y_axis_scale_min field */	
		// Initial state
		if(!isset($_POST['y_axis_scale_min']))
		{
			$_POST['y_axis_scale_min'] = -5;
		}
		// Field is not filled
		else if($_POST['y_axis_scale_min'] == '')
		{
			array_push($PLOT->ERROR_MESSAGES, '- Y AXIS error: Filling <i>Scale MIN</i> field is required. <br>');
		}
		// Field is filled with invalid data
		else if(!is_numeric($_POST['y_axis_scale_min']))
		{
			array_push($PLOT->ERROR_MESSAGES, '- Y AXIS error: <i>Scale MIN</i> must be numeric. <br>');
		}
		// Field is filled with invalid number when scale type is LOG
		else if( ($_POST['y_axis_scale'] == 'logarithm' ) &&  $_POST['y_axis_scale_min'] <= 0)
		{
			array_push($PLOT->ERROR_MESSAGES, '- Y AXIS error: Minimum of <i>logarithm</i> scale must be grather than 0. <br>');
		}
		// Field is filled with invalid number when scale type is LOG
		else if( ($_POST['y_axis_scale'] == 'root' || $_POST['y_axis_scale'] == 'power') &&  $_POST['y_axis_scale_min'] < 0)
		{
			array_push($PLOT->ERROR_MESSAGES, '- Y AXIS error: Minimum of <i>root</i> / <i>power</i> scale must be grather or equal than 0. <br>');
		}
		// Field is filled with invalid number when scale type is reciprocal
		else if( ($_POST['y_axis_scale'] == 'reciprocal') &&  $_POST['y_axis_scale_min'] >= -1)
		{
			array_push($PLOT->ERROR_MESSAGES, '- Y AXIS error: Minimum of <i>reciprocal</i> scale must be less than -1. <br>');
		}
		// Field is filled with invalid number when scale type is tan
		else if( ($_POST['y_axis_scale'] == 'tan' ) &&  $_POST['y_axis_scale_min'] <= -1.5707963267949)
		{
			array_push($PLOT->ERROR_MESSAGES, '- Y AXIS error: Minimum of <i>tan</i> scale must be grather than -1.5707963267949. <br>');
		}
		// Field is filled with invalid number when scale type is tan
		else if( ($_POST['y_axis_scale'] == 'atanh' ) &&  $_POST['y_axis_scale_min'] <= -1)
		{
			array_push($PLOT->ERROR_MESSAGES, '- Y AXIS error: Minimum of <i>atanh</i> scale must be grather than -1. <br>');
		}
		// Field is filled with invalid number when scale type is normal
		else if( ($_POST['y_axis_scale'] == 'lognormal' ) &&  $_POST['y_axis_scale_min'] <= 0)
		{
			array_push($PLOT->ERROR_MESSAGES, '- Y AXIS error: Minimum of <i>lognormal</i> scale must be grather than 0. <br>');
		}

	/* Y_axis_scale_max field */	
		// Initial state
		if(!isset($_POST['y_axis_scale_max']))
		{
			$_POST['y_axis_scale_max'] = 5;
		}
		// Field is not filled
		else if($_POST['y_axis_scale_max'] == '')
		{
			array_push($PLOT->ERROR_MESSAGES, '- Y AXIS error: Filling <i>Scale MAX</i> field is required. <br>');
		}
		// Field is filled with invalid data
		else if(!is_numeric($_POST['y_axis_scale_max']))
		{
			array_push($PLOT->ERROR_MESSAGES, '- Y AXIS error: <i>Scale MAX</i> must be numeric. <br>');
		}
		else if( ($_POST['y_axis_scale'] == 'reciprocal') &&  $_POST['y_axis_scale_max'] <= 1)
		{
			array_push($PLOT->ERROR_MESSAGES, '- Y AXIS error: Maximum of <i>reciprocal</i> scale must be greater than 1. <br>');
		}
		// Field is filled with invalid number when scale type is tan
		else if( ($_POST['y_axis_scale'] == 'tan' ) &&  $_POST['y_axis_scale_max'] >= 1.5707963267949)
		{
			array_push($PLOT->ERROR_MESSAGES, '- Y AXIS error: Maximum of <i>tan</i> scale must be less than 1.5707963267949. <br>');
		}
		// Field is filled with invalid number when scale type is tan
		else if( ($_POST['y_axis_scale'] == 'atanh' ) &&  $_POST['y_axis_scale_max'] >= 1)
		{
			array_push($PLOT->ERROR_MESSAGES, '- Y AXIS error: Maximum of <i>atanh</i> scale must be less than 1. <br>');
		}

	/* Y_tick_anchor field */	
		// Initial state
		if(!isset($_POST['y_tick_anchor']) || $_POST['y_tick_anchor'] == '')
		{
			$PLOT->SetYTickAnchor(1);
		}
		// Field is filled with invalid data
		else if(!is_numeric($_POST['y_tick_anchor']))
		{
			array_push($PLOT->ERROR_MESSAGES, '- Y AXIS error: <i>Tick anchor</i> must be numeric. <br>');
		}
		// Normal case
		else
		{	
			$PLOT->SetYTickAnchor($_POST['y_tick_anchor']);
		}

	/* Y_tick_increment field */	
		// Initial state
		if(!isset($_POST['y_tick_increment']) || $_POST['y_tick_increment'] == '')
		{
			$PLOT->SetYTickIncrement(1);
		}
		// Field is filled with invalid data
		else if(!is_numeric($_POST['y_tick_increment']))
		{
			array_push($PLOT->ERROR_MESSAGES, '- Y AXIS error: <i>Tick increment</i> must be numeric. <br>');
		}
		// Tick increment is equal or less than 0
		else if($_POST['y_tick_increment'] <= 0)
		{
			array_push($PLOT->ERROR_MESSAGES, '- Y AXIS error: Tick incrementation value must be greater than 0. <br>');
		}
		// Normal case
		else
		{
			$PLOT->SetYTickIncrement($_POST['y_tick_increment']);
		}

	/* Y_draw_grid field */	
		// Initial state
		if(!isset($_POST['y_draw_grid']))
		{
			$PLOT->SetDrawYGrid(TRUE);
		}
		// Normal case
		else
		{
			if($_POST['y_draw_grid'] == 'true') 
			{
				$PLOT->SetDrawYGrid(TRUE);
			}
			else 
			{
				$PLOT->SetDrawYGrid(FALSE);
			}
		}

	/* X_axis_position field (hidden) */	
		// Initial state
		if($_POST['y_axis_scale'] == 'logarithm' )
		{
			$PLOT->SetXAxisPosition(1);
		}
		else if($_POST['y_axis_scale'] == 'exponent' )
		{
			$PLOT->SetXAxisPosition($_POST['x_axis_scale_min']);
		}
		else if($_POST['y_axis_scale'] == 'normal' )
		{
			$PLOT->set_x_axis_pos(0.5);
		}
		else
		{
			$PLOT->SetXAxisPosition(0);
		}


/* Checking scale size > 0  and creating coordinate system*/
	// X 
	if($_POST['x_axis_scale_max'] <= $_POST['x_axis_scale_min'])
	{
		if($_POST['x_axis_scale_max'] != '' && $_POST['x_axis_scale_min'] != '' && is_numeric($_POST['x_axis_scale_max']) && is_numeric($_POST['x_axis_scale_min']))
		{
			if($_POST['x_axis_scale'] == 'reciprocal')
			{

			}
			else
			{
				array_push($PLOT->ERROR_MESSAGES, '- X AXIS error: Axis range must be greater than 0. <br>');
			}
			
		}
	}
	// Y 
	else if($_POST['y_axis_scale_max'] <= $_POST['y_axis_scale_min'])
	{
		if($_POST['y_axis_scale_max'] != '' && $_POST['y_axis_scale_min'] != '' && is_numeric($_POST['y_axis_scale_max']) && is_numeric($_POST['y_axis_scale_min']))
		{
			if($_POST['y_axis_scale'] == 'reciprocal')
			{

			}
			else
			{
				array_push($PLOT->ERROR_MESSAGES, '- Y AXIS error: Axis range must be greater than 0. <br>');
			}
		}
	}
	// Creating coordinate system
	else
	{
		$PLOT->SetPlotAreaWorld($_POST['x_axis_scale_min'], $_POST['y_axis_scale_min'], $_POST['x_axis_scale_max'], $_POST['y_axis_scale_max']);
	}

/* Setting other plot properties */
	// Image border
	$PLOT->SetImageBorderType('plain');

	$PLOT->SetPrintImage(FALSE);

	// Not to draw lines through 'empty' points
	// $PLOT->SetDrawBrokenLines(TRUE);

	// Plot type
	$PLOT->SetPlotType('points');
	$PLOT->SetPointShapes('dot');

	// Data type
	$PLOT->SetDataType('data-data');	

	// Tick label position
	$PLOT->SetXTickLabelPos('xaxis'); 
	$PLOT->SetYTickLabelPos('yaxis');

	// Skip last/first tick
	// $PLOT->SetSkipBottomTick(TRUE);
	// $PLOT->SetSkipTopTick(TRUE);
	// $PLOT->SetSkipLeftTick(TRUE);
	// $PLOT->SetSkipRightTick(TRUE);
	
	// Tick color
	$PLOT->SetTickColor('grey'); 

	// Plot border
	$PLOT->SetPlotBorderType('none');

	// Label position
	$PLOT->SetXLabel('X axis');
	$PLOT->SetYLabel('Y axis');

	// Tick axis crossing
	$PLOT->SetXTickLength(4);
	$PLOT->SetXTickCrossing(3);
	$PLOT->SetYTickLength(3);
	$PLOT->SetYTickCrossing(2);
	
	// Tick position
	$PLOT->SetXTickPos('xaxis');
	$PLOT->SetYTickPos('yaxis');

	// Plot margins
	// $PLOT->SetMarginsPixels(10, 10, 10, 10);

/* Drawing plot */
	if(!count($PLOT->ERROR_MESSAGES))
	{
		$PLOT->SetDataColors('red');
		$PLOT->SetDataValues($PLOT->CalculateFunctionData($new_function1));
		$PLOT->print_debug('debug');	
		$PLOT->print_plot_data('saved_plot_data');
		$PLOT->DrawGraph();

		if($new_function2 != NULL)
		{
			$PLOT->SetDataColors('black');
			$PLOT->SetDataValues($PLOT->CalculateFunctionData($new_function2));
			$PLOT->DrawGraph();
		}
		if($new_function3 != NULL)
		{
			$PLOT->SetDataColors('SkyBlue');
			$PLOT->SetDataValues($PLOT->CalculateFunctionData($new_function3));
			$PLOT->DrawGraph();
		}
		if($new_function4 != NULL)
		{
			$PLOT->SetDataColors('YellowGreen');
			$PLOT->SetDataValues($PLOT->CalculateFunctionData($new_function4));
			$PLOT->DrawGraph();
		}
		$PLOT->PrintImage();

	}
/* Printing error messages */
	else
	{
		for($i=0; $i<count($PLOT->ERROR_MESSAGES); $i++)
		{
			print $PLOT->ERROR_MESSAGES[$i];
		}
	}

?>
